==> igniteui-react-16.16.2.tgz: package/esm5/lib/CardActions.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CardActionsOrientation_$type } from "./CardActionsOrientation";
/**
 * @hidden
 */
var CardActions = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CardActions, _super);
    function CardActions() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(CardActions.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CardActions.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.d = this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CardActions.prototype, "a", {
        get: function () {
            var ret_ = this.c.c("orientation");
            ret_ = enumGetBox(CardActionsOrientation_$type, EnumUtil.getEnumValue(CardActionsOrientation_$type, EnumUtil.parse(CardActionsOrientation_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CardActionsOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CardActionsOrientation_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    CardActions.$t = markType(CardActions, 'CardActions', BaseElement.$);
    return CardActions;
}(BaseElement));
export { CardActions };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/CardActions.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CardActionsOrientation_$type } from "./CardActionsOrientation";
/**
 * @hidden
 */
var CardActions = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CardActions, _super);
    function CardActions() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(CardActions.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CardActions.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    CardActions.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(CardActions.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("orientation");
            ret_ = enumGetBox(CardActionsOrientation_$type, EnumUtil.getEnumValue(CardActionsOrientation_$type, this.c.f(CardActionsOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CardActionsOrientation_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CardActionsOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("orientation", value_);
        },
        enumerable: false,
        configurable: true
    });
    CardActions.$t = markType(CardActions, 'CardActions', BaseElement.$);
    return CardActions;
}(BaseElement));
export { CardActions };
